@@ -1,5 +1,5 @@
 #
-# Copyright 2007, 2008, 2009 David Snopek <dsnopek@gmail.com>
+# Copyright 2007-2010 David Snopek <dsnopek@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 package POE::Component::MessageQueue;
 use Moose;
 
-our $VERSION = '0.2.8';
+our $VERSION = '0.2.9';
 
 use POE 0.38;
 use POE::Component::Server::Stomp;
@@ -517,8 +517,8 @@ POE::Component::MessageQueue - A POE message queue that uses STOMP for its commu
 If you are only interested in running with the recommended storage backend and
 some predetermined defaults, you can use the included command line script:
 
-  POE::Component::MessageQueue version 0.2.6
-  Copyright 2007, 2008, 2009 David Snopek (http://www.hackyourlife.org)
+  POE::Component::MessageQueue version 0.2.9
+  Copyright 2007-2010 David Snopek (http://www.hackyourlife.org)
   Copyright 2007, 2008 Paul Driver <frodwith@gmail.com>
   Copyright 2007 Daisuke Maki <daisuke@endeworks.jp>
   
@@ -927,7 +927,7 @@ L<http://www.activemq.org/> -- ActiveMQ is a popular Java-based message queue
 
 =head1 UPGRADING FROM OLDER VERSIONS
 
-If you used any of the following storage engines with PoCo::MQ 0.1.7 or older:
+If you used any of the following storage engines with PoCo::MQ 0.2.9 or older:
 
 =over 4
 
@@ -962,6 +962,11 @@ the above upgrade script.  This one has a SQLite specific version: upgrade-0.1.8
 upgrade-0.2.3.sql -- Apply if you are upgrading from version 0.2.2 or older or after
 applying the above upgrade script.
 
+=item *
+
+upgrade-0.2.9-mysql.sql -- Doesn't apply to SQLite users!  Apply if you are upgrading from version
+0.2.8 or older or after applying the above upgrade script.
+
 =back
 
 =head1 CONTACT
@@ -1099,7 +1104,7 @@ thousands of large messages daily and we experience very few issues.
 
 =head1 AUTHORS
 
-Copyright 2007, 2008, 2009 David Snopek (L<http://www.hackyourlife.org>)
+Copyright 2007-2010 David Snopek (L<http://www.hackyourlife.org>)
 
 Copyright 2007, 2008 Paul Driver <frodwith@gmail.com>
 
