@@ -11,7 +11,7 @@ CREATE TABLE messages
 (
 	message_id  varchar(255) primary key,
 	destination varchar(255) not null,
-	persistent  char(1) default 'Y' not null,
+	persistent  char(1) default '1' not null,
 	in_use_by   int,
 	body        text,
 	timestamp   int,
